#########
# Author:        rmp
# Last Modified: $Date$
# Id:            $Id$
# Source:        $Source$
# $HeadURL$
#
use strict;
use warnings;
use Module::Build;

my $builder = Module::Build->new(
				 module_name         => 'Text-Sass',
				 dist_author         => 'Roger Pettett <rmp@psyphi.net>',
				 dist_version        => do { require 'lib/Text/Sass.pm'; $Text::Sass::VERSION; },
				 dist_abstract       => q[Text-Sass - Perl implementation of http://sass-lang.com/],
				 license             => 'perl',
				 requires            => {
							 'Carp'                        => '1.04',
							 'strict'                      => '1.03',
							 'warnings'                    => '1.05',
							},
				 recommends          => {
							},
				 build_requires      => {
							 'Test::Distribution'      => '2.00',
							 'Test::More'              => '0.8',
							 'Test::Perl::Critic'      => '1.01',
							},
				 build_recommends    => {
							},
				 create_makefile_pl  => 'passthrough',
#				 script_files        => qw(),
				 sign                => 1,
				);

$builder->create_build_script();
